@@ -1,13 +1,6 @@
 #
 # Copyright (c) 2020-2021 Pinecone Systems Inc. All right reserved.
 #
-
-from pinecone.utils.tracing import init_tracer
-init_tracer()
-
-import ddtrace
-ddtrace.patch_all()
-
 import os
 import configparser
 from loguru import logger
