@@ -2,6 +2,10 @@
 # Copyright (c) 2020-2021 Pinecone Systems Inc. All right reserved.
 #
 
+from pinecone.utils.tracing import init_tracer, init_profiler
+init_tracer()
+init_profiler()
+
 import argparse
 from pinecone.network.zmq_service import ZMQService
 
