@@ -5,6 +5,7 @@
 from pinecone.functions.index import Index
 from pinecone.protos import core_pb2
 from pinecone.utils import load_numpy, dump_numpy
+from pinecone.utils.constants import MAX_ID_LENGTH
 import numpy as np
 
 from typing import Iterable, Tuple
@@ -82,16 +83,25 @@ class VectorIndex(Index):
         if self.dimension() and data.shape[1] != self.dimension():
             raise ValueError(f"Data dimension must be consistent {data.shape[1]} != {self.dimension()}")
 
+    @staticmethod
+    def validate_ids(ids: Iterable[str]):
+        if any(len(id_) > MAX_ID_LENGTH for id_ in ids):
+            raise ValueError(f"Vector IDs should be no longer than {MAX_ID_LENGTH} characters")
+
     def handle_msg(self, msg: 'core_pb2.Request') -> 'core_pb2.Request':
         req_type = msg.WhichOneof('body')
         if req_type == 'delete':
             self.delete_data(msg.delete.ids)
         elif req_type == 'index':
+            if self.full:
+                raise RuntimeError("Index is full, cannot accept upserts")
+            VectorIndex.validate_ids(msg.index.ids)
             data = VectorIndex.downcast_data(load_numpy(msg.index.data))
             if len(data.shape) == 1:
                 data = data.reshape(1, -1)
             self.validate_dimension(data)
             self.add_data(data, msg.index.ids)
+            msg.index.data.Clear()  # data is not needed along the way
         elif req_type == 'query':
             vectors = VectorIndex.downcast_data(load_numpy(msg.query.data))
             if len(vectors.shape) == 1:
