@@ -14,7 +14,7 @@ class DotProductRanker(Ranker):
         super().__init__(*args, **kwargs)
 
     def batch_dotproduct(self, xx, uu):
-        return np.dot(xx, np.transpose(uu))
+        return np.einsum('ij,kj->ik', xx, uu)
 
     def score(self, q: np.ndarray, vectors: np.ndarray, prev_scores: Iterable[float]) -> Iterable[float]:
-        return self.batch_dotproduct(q, vectors).flatten()
+        return self.batch_dotproduct(vectors, q).flatten()
