@@ -126,7 +126,7 @@ class ZMQService(Runnable):
             if new_offset is None:
                 return
 
-        loop = asyncio.get_running_loop()
+        loop = asyncio.get_event_loop()
         if self.executor is None:
             self.executor = concurrent.futures.ThreadPoolExecutor(max_workers=1)
         try:
